@@ -83,7 +83,7 @@ class BaseDriver(RemoteWebDriver):
         self._agent_client: AgentClient = AgentClient(
             token=self._token,
             capabilities=capabilities,
-            reportsettings=ReportSettings(self._projectname, self._jobname),
+            report_settings=ReportSettings(self._projectname, self._jobname),
         )
         self._agent_session: AgentSession = self._agent_client.agent_session
         self.w3c = True if self._agent_session.dialect == "W3C" else False
@@ -138,7 +138,7 @@ class BaseDriver(RemoteWebDriver):
         Returns:
             AddonHelper: object giving access to addon proxy methods
         """
-        return AddonHelper(self._agent_client)
+        return AddonHelper(self._agent_client, self.command_executor)
 
     def quit(self):
         """Quits the driver and stops the session with the Agent, cleaning up after itself"""
