@@ -11,7 +11,9 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import logging
+import os
 
 from src.testproject.helpers import ReportHelper
 from src.testproject.rest.messages import StepReport, CustomTestReport
@@ -20,17 +22,19 @@ from src.testproject.rest.messages import StepReport, CustomTestReport
 class Reporter:
     """Exposes reporting actions to the WebDriver object
 
-        Args:
-            command_executor: the command executor associated with the driver
+    Args:
+        command_executor: the command executor associated with the driver
 
-        Attributes:
-            _command_executor: the command executor associated with the driver
+    Attributes:
+        _command_executor: the command executor associated with the driver
     """
 
     def __init__(self, command_executor):
         self._command_executor = command_executor
 
-    def step(self, description: str, message: str, passed: bool, screenshot: bool = False):
+    def step(
+        self, description: str, message: str, passed: bool, screenshot: bool = False
+    ):
         """Sends a step report to the Agent Client
 
         Args:
@@ -46,7 +50,10 @@ class Reporter:
         if not self._command_executor.disable_reports:
 
             step_report = StepReport(
-                description, message, passed, self._command_executor.create_screenshot() if screenshot else None,
+                description,
+                message,
+                passed,
+                self._command_executor.create_screenshot() if screenshot else None,
             )
             self._command_executor.agent_client.report_step(step_report)
         else:
@@ -65,10 +72,11 @@ class Reporter:
                 name = ReportHelper.infer_test_name()
 
             if not self._command_executor.disable_auto_test_reports:
-                logging.warning(
-                    "Automatic reporting is enabled, disable this using disable_reports flag "
-                    "when creating a driver instance to avoid duplicates in the report"
-                )
+                if os.getenv("RFW_SUPPRESS_WARNINGS", "false").casefold() != "true":
+                    logging.warning(
+                        "Automatic reporting is enabled, disable this using disable_reports flag "
+                        "when creating a driver instance to avoid duplicates in the report"
+                    )
 
             test_report = CustomTestReport(name=name, passed=passed, message=message,)
 
@@ -108,3 +116,11 @@ class Reporter:
             disabled (bool): Set to True to disable driver command report redaction.
         """
         self._command_executor.disable_redaction = disabled
+
+    def exclude_test_names(self, excluded_test_names: list):
+        """Excludes a list of test names (as strings) from being reported
+
+        Args:
+            excluded_test_names: list of strings containing tests that should not be reported.
+        """
+        self._command_executor.excluded_test_names = excluded_test_names
